@@ -1,42 +1,59 @@
 from __future__ import absolute_import
+
 import datetime
 import json
+import re
 
+import iso8601
 import six
 
-
 DATE_FMT = "%Y-%m-%d"
 ISO8601_FMT = "%Y-%m-%dT%H:%M:%SZ"
 JAVASCRIPT_FMT = "datetime.datetime(%Y, %m, %d, %H, %M, %S)"
-
-
-try:
-    # Python 3
-    from datetime import timezone
-
-    UTC = timezone.utc
-except ImportError:
-    # Python 2
-    class UTC(datetime.tzinfo):
-        def utcoffset(self, dt):
-            return datetime.timedelta(0)
-
-        def tzname(self, dt):
-            return "UTC"
-
-        def dst(self, dt):
-            return datetime.timedelta(0)
-
-    UTC = UTC()
+ISO_8601_DT_REGEX = re.compile(
+    r"""
+    (?P<year>[0-9]{4})
+    (
+        (
+            (-(?P<monthdash>[0-9]{1,2}))
+            |
+            (?P<month>[0-9]{2})
+            (?!$)  # Don't allow YYYYMM
+        )
+        (
+            (
+                (-(?P<daydash>[0-9]{1,2}))
+                |
+                (?P<day>[0-9]{2})
+            )
+            (?P<separator>[ T])
+            (?P<hour>[0-9]{2})
+            (:?(?P<minute>[0-9]{2})){0,1}
+            (
+                :?(?P<second>[0-9]{1,2})
+                ([.,](?P<second_fraction>[0-9]+)){0,1}
+            )?
+            (?P<timezone>
+                Z
+                |
+                (
+                    (?P<tz_sign>[-+])
+                    (?P<tz_hour>[0-9]{2})
+                    :{0,1}
+                    (?P<tz_minute>[0-9]{2}){0,1}
+                )
+            )?
+        )
+    )
+    $
+    """,
+    re.VERBOSE,
+)
 
 
 def _datetime_encoder(obj):
     if isinstance(obj, datetime.datetime):
-        try:
-            return obj.strftime(ISO8601_FMT)
-        except ValueError:
-            # Prior to 1900 in Py2
-            return "%sZ" % obj.isoformat().split("+")[0]
+        return obj.isoformat()
     elif isinstance(obj, datetime.date):
         try:
             return obj.strftime(DATE_FMT)
@@ -55,12 +72,14 @@ def _datetime_decoder(dict_):
         if value == "":
             dict_[key] = six.text_type()
             continue
+        elif value is None:
+            dict_[key] = None
+            continue
 
-        try:
-            dict_[key] = datetime.datetime.strptime(
-                value, ISO8601_FMT
-            ).replace(tzinfo=UTC)
-        except (ValueError, TypeError):
+        m = ISO_8601_DT_REGEX.match(value)
+        if m:
+            dict_[key] = iso8601.parse_date(value)
+        else:
             try:
                 date_obj = datetime.datetime.strptime(value, DATE_FMT)
                 dict_[key] = date_obj.date()
